effective_recovery_probability

Function effective_recovery_probability 

pub fn effective_recovery_probability(stabilities: &[f64], k: usize) -> f64
Recompute the rolling effective recovery probability Pe for a file that was uploaded with threshold k, given the current stability scores.

This is called periodically by the daemon to update pe in the FileManifest.

Pe = P(X ≥ k)  ≈  1 − Φ((k − 0.5 − μ) / σ)